@@ -37,7 +37,6 @@ find("objects")
 
 get("[<-.data.frame", pos = 2)
 
-data(hills)
 # hills <- hills  # only needed in S-PLUS
 hills$ispeed <- hills$time/hills$dist
 
@@ -64,7 +63,6 @@ Empl <- c(Empl, service = 8)
 
 c(list(x = 1:3, a = 3:6), list(y = 8:23, b = c(3, 8, 39)))
 
-library(methods)
 as(powers.of.pi, "vector")
 as(powers.of.pi, "numeric")
 is(powers.of.pi, "numeric")
